summaryrefslogtreecommitdiffstats
path: root/chrome/views/tooltip_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/views/tooltip_manager.h')
-rw-r--r--chrome/views/tooltip_manager.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/views/tooltip_manager.h b/chrome/views/tooltip_manager.h
index f1aab66a..2800fb0 100644
--- a/chrome/views/tooltip_manager.h
+++ b/chrome/views/tooltip_manager.h
@@ -13,11 +13,11 @@ class ChromeFont;
namespace views {
-class Container;
class View;
+class Widget;
// TooltipManager takes care of the wiring to support tooltips for Views.
-// This class is intended to be used by Containers. To use this, you must
+// This class is intended to be used by Widgets. To use this, you must
// do the following:
// Add the following to your MSG_MAP:
//
@@ -57,8 +57,8 @@ class TooltipManager {
// Returns the separator for lines of text in a tooltip.
static const std::wstring& GetLineSeparator();
- // Creates a TooltipManager for the specified Container and parent window.
- TooltipManager(Container* container, HWND parent);
+ // Creates a TooltipManager for the specified Widget and parent window.
+ TooltipManager(Widget* widget, HWND parent);
virtual ~TooltipManager();
// Notification that the view hierarchy has changed in some way.
@@ -123,8 +123,8 @@ class TooltipManager {
// Invoked when the timer elapses and tooltip has to be destroyed.
void DestroyKeyboardTooltipWindow(HWND window_to_destroy);
- // Hosting view container.
- Container* container_;
+ // Hosting Widget.
+ Widget* widget_;
// The View the mouse is under. This is null if the mouse isn't under a
// View.